@@ -54,39 +54,41 @@ class HackerNewsApp:
 
         # The default state is false, and it toggles when you click on it
         self.commentState = args.comments
+        self.reverse = args.reverse
 
         # create items for the menu - refresh, quit and a separator
         menuSeparator = Gtk.SeparatorMenuItem()
         menuSeparator.show()
-        self.menu.append(menuSeparator)
+        self.add(menuSeparator)
 
         btnComments = Gtk.CheckMenuItem("Show Comments")
         btnComments.show()
         btnComments.set_active(args.comments)
+        btnComments.set_draw_as_radio(True)
         btnComments.connect("activate", self.toggleComments)
-        self.menu.append(btnComments)
+        self.add(btnComments)
 
         btnAbout = Gtk.MenuItem("About")
         btnAbout.show()
         btnAbout.connect("activate", self.showAbout)
-        self.menu.append(btnAbout)
+        self.add(btnAbout)
 
         btnRefresh = Gtk.MenuItem("Refresh")
         btnRefresh.show()
         # the last parameter is for not running the timer
         btnRefresh.connect("activate", self.refresh, True, args.chrome)
-        self.menu.append(btnRefresh)
+        self.add(btnRefresh)
 
         if Version.new_available():
             btnUpdate = Gtk.MenuItem("New Update Available")
             btnUpdate.show()
             btnUpdate.connect('activate', self.showUpdate)
-            self.menu.append(btnUpdate)
+            self.add(btnUpdate)
 
         btnQuit = Gtk.MenuItem("Quit")
         btnQuit.show()
         btnQuit.connect("activate", self.quit)
-        self.menu.append(btnQuit)
+        self.add(btnQuit)
         self.menu.show()
         self.ind.set_menu(self.menu)
 
@@ -94,6 +96,12 @@ class HackerNewsApp:
             args.firefox = Firefox.default_firefox_profile_path()
         self.refresh(chrome_data_directory=args.chrome, firefox_data_directory=args.firefox)
 
+    def add(self, item):
+        if self.reverse:
+            self.menu.prepend(item)
+        else:
+            self.menu.append(item)
+
     def toggleComments(self, widget):
         """Whether comments page is opened or not"""
         self.commentState = not self.commentState
@@ -125,7 +133,7 @@ class HackerNewsApp:
         Gtk.main()
         return 0
 
-    def open(self, widget, event=None, data=None):
+    def open(self, widget, **args):
         """Opens the link in the web browser"""
         # We disconnect and reconnect the event in case we have
         # to set it to active and we don't want the signal to be processed
@@ -137,6 +145,8 @@ class HackerNewsApp:
         self.db.add(widget.item_id)
         webbrowser.open(widget.url)
 
+        # TODO: Add support for Shift+Click or Right Click
+        # to do the opposite of the current commentState setting
         if self.commentState:
             webbrowser.open(self.HN_URL_PREFIX + str(widget.hn_id))
 
@@ -146,8 +156,12 @@ class HackerNewsApp:
         if item['points'] == 0 or item['points'] is None:
             return
 
-        i = Gtk.CheckMenuItem(
-            "(" + str(item['points']).zfill(3) + "/" + str(item['comments_count']).zfill(3) + ")    " + item['title'])
+        points = str(item['points']).zfill(3) + "/" + str(item['comments_count']).zfill(3)
+
+        i = Gtk.CheckMenuItem.new_with_label(label="(" + points + ")"+item['title'])
+        label = i.get_child()
+        label.set_markup("<tt>" + points + "</tt> <span>"+item['title']+"</span>".format(points=points, title=item['title']))
+        label.set_selectable(False)
 
         visited = item['history'] or item['id'] in self.db
 
@@ -158,7 +172,10 @@ class HackerNewsApp:
         i.signal_id = i.connect('activate', self.open)
         i.hn_id = item['id']
         i.item_id = item['id']
-        self.menu.prepend(i)
+        if self.reverse:
+            self.menu.append(i)
+        else:
+            self.menu.prepend(i)
         i.show()
 
     def refresh(self, widget=None, no_timer=False, chrome_data_directory=None, firefox_data_directory=None):
@@ -204,11 +221,10 @@ class HackerNewsApp:
 def main():
     parser = argparse.ArgumentParser(description='Hacker News in your System Tray')
     parser.add_argument('-v', '--version', action='version', version=Version.current())
-    parser.add_argument('-c', '--comments', dest='comments', action='store_true', help="Load the HN comments link for the article as well")
+    parser.add_argument('-c', '--comments', dest='comments', default=False, action='store_true', help="Load the HN comments link for the article as well")
     parser.add_argument('--chrome', dest='chrome', help="Specify a Google Chrome Profile directory to use for matching chrome history")
     parser.add_argument('--firefox', dest='firefox', help="Specify a Firefox Profile directory to use for matching firefox history. Pass auto to automatically pick the default profile")
-    parser.set_defaults(comments=False)
-    parser.set_defaults(dnt=False)
+    parser.add_argument('-r', '--reverse', dest='reverse', default=False, action='store_true', help="Reverse the order of items. Use if your status bar is at the bottom of the screen")
     args = parser.parse_args()
     indicator = HackerNewsApp(args)
     indicator.run()
